@@ -11,11 +11,11 @@ sys.path.append(package_path)
 files = os.listdir(package_path)
 
 for file in files:
-    module = Path(file).stem
-
-    if not module.endswith('tools'):  # specific to this package
+    if not file.startswith('itb_'):
         continue
 
+    module = Path(file).stem
+
     exec(
         f'from .{module} import *'
     )
