@@ -9,11 +9,28 @@ from typing import Union
 import DateTime
 import datetime
 import vobject
-from itb_date_time import convert_datetime
+from dateutil.parser import parse
+from itb_date_time import convert_datetime, str_to_date, str_to_DT, get_dateformat
 from itb_email_phone import process_phonenumber
 
 comma_float_chars = set(',1234567890')
 datetime_chars = set('1234567890.-:/+ ')
+time_chars = set('1234567890:')
+
+
+def any_2boolean(
+    value
+) -> bool:
+    """ return a boolean for any value
+
+    This function recognizes strings and bytes that signifie False, such as "False" or "0"
+    """
+    if not value:
+        return False
+    elif isinstance(value, (str, bytes)):
+        if value.lower() in ('0', 'false', b'0', b'false'):
+            return False
+    return True
 
 
 def dict_from_dict_list(
@@ -136,10 +153,10 @@ def dict_2unicode(
 
 def dict_2datatypes(
     d: dict,
-    json_data: str = None,
+    metadata: dict = {},
     convert_keys: bool = False,
     convert_to_unicode: bool = False,
-    dt: str = 'DateTime',
+    dt: str = 'datetime',
     fmt: str = '%d.%m.%Y'
 ) -> dict:
     """ convert all data of a dictionary to specific (json metadata) or guessed types """
@@ -153,7 +170,7 @@ def dict_2datatypes(
                 fmt=fmt
             ): value_2datatype(
                 value=val,
-                json_data=json_data,
+                typ=metadata.get(key),
                 key=key,
                 convert_to_unicode=convert_to_unicode,
                 dt=dt,
@@ -165,7 +182,7 @@ def dict_2datatypes(
         return {
             key: value_2datatype(
                 value=val,
-                json_data=json_data,
+                typ=metadata.get(key),
                 key=key,
                 convert_to_unicode=convert_to_unicode,
                 dt=dt,
@@ -177,7 +194,7 @@ def dict_2datatypes(
 
 def dictlist_2datatypes(
     dictlist: str,
-    json_data: str = None,
+    metadata: dict = {},
     convert_keys: bool = False,
     convert_to_unicode: bool = False,
     dt: str = 'datetime',
@@ -186,7 +203,7 @@ def dictlist_2datatypes(
     return [
         dict_2datatypes(
             d=dic,
-            json_data=json_data,
+            metadata=metadata,
             convert_keys=convert_keys,
             convert_to_unicode=convert_to_unicode,
             dt=dt
@@ -234,11 +251,11 @@ def sort_dictlist(
 
 def value_2datatype(
     value,
-    json_data: str = None,
+    typ: str = None,
     key: str = None,
     convert_to_unicode: bool = False,
     encoding: str = 'utf-8',
-    dt: str = 'DateTime',
+    dt: str = 'datetime',
     fmt: str = '%d.%m.%Y',  # only for datetime
     UTC: bool = False
 ) -> Union[str, int, float]:
@@ -246,70 +263,87 @@ def value_2datatype(
 
     this function has two modes:
 
-    1. it uses a json file with the metadata (types of variables by name)
-    2. it makes educated guesses in converting a string (don't feed bytes to this function!)
+    1. it is provided a type for the conversion
+    2. it makes educated guesses in converting a string
 
     :param value:
-    :param json_data: metadata
-    :param key: key in the json_data (value name)
+    :param metadata: dictionary containing types for the keys:
+               - boolean
+               - int
+               - float
+               - date
+               - datetime: date and time
+               - time: conversion or not based on dt
+    :param key: key in the metadata (value name)
     :param convert_to_unicode: convert all bytes to unicode in the process
     :param encoding: if bytes are present, use this encoding to convert them to unicode
     :param dt: - datetime or dt
                - DateTime or DT
-               - default: DateTime, because it's Zope's default
+               - default: datetime, because it's Python's default
     """
-
-    if json_data:
-        typ = json_data.get(key)
-        if not typ:
-            return value
-        else:
-            if typ == 'int':
+    if typ:
+        if typ == 'boolean':
+            return any_2boolean(value=value)
+        if typ == 'int':
+            try:
+                return int(value)
+            except ValueError:
+                return value
+        elif typ == 'float':
+            value = value.replace(',', '.')
+            try:
+                return float(value)
+            except ValueError:
+                return value
+        elif typ == 'date':
+            if dt in ('datetime', 'dt'):
+                return convert_datetime(
+                    value,
+                    convert_to='date',
+                    fmt=fmt
+                )
+            elif dt in ('DateTime', 'DT'):
+                if ' ' in value:
+                    value = value.split()[0]  # get rid of time
+                return DateTime.DateTime(
+                    value,
+                    datefmt='international'
+                ) + 0.5  # to avoid day-shifting due to timezones, use 12am
+            elif dt in ('ignore', 'string'):
+                return value
+            else:
+                raise Exception(f'invalid value {dt} for argument dt')
+        elif typ == 'datetime':
+            if dt in ('datetime', 'dt'):
+                return datetime.datetime.strptime(value, fmt)
+            elif dt in ('DateTime', 'DT'):
+                value = value.strip()
                 try:
-                    return int(value)
-                except ValueError:
-                    return value
-            elif typ == 'float':
-                value = value.replace(',', '.')
-                try:
-                    return float(value)
-                except ValueError:
-                    return value
-            elif typ == 'date':
-                if dt in ('datetime', 'dt'):
-                    return convert_datetime(
-                        value,
-                        convert_to='date',
-                        fmt=fmt
-                    )
-                elif dt in ('DateTime', 'DT'):
-                    if ' ' in value:
-                        value = value.split()[0]  # get rid of time
                     return DateTime.DateTime(
                         value,
                         datefmt='international'
-                    ) + 0.5  # to avoid day-shifting due to timezones, use 12am
-                else:
-                    raise Exception('argument dt must be datetime, dt, DateTime or DT')
-            elif typ == 'datetime':
-                if dt in ('datetime', 'dt'):
-                    return datetime.datetime.strptime(value, fmt)
-                elif dt in ('DateTime', 'DT'):
-                    value = value.strip()
-                    try:
-                        return DateTime.DateTime(
-                            value,
-                            datefmt='international'
-                        )
-                    except DateTime.interfaces.SyntaxError:
-                        return value
-                else:
-                    raise Exception('argument dt must be datetime, dt, DateTime or DT')
-    else:
-        original_value = value
+                    )
+                except DateTime.interfaces.SyntaxError:
+                    return value
+            elif dt in ('ignore', 'string'):
+                return value
+            else:
+                raise Exception(f'invalid value {dt} for argument dt')
+        elif 'time' in typ:
+            if 'datetime' in typ or dt in ('datetime', 'dt'):
+                dt = parse(value)
+                return dt.time()
+            else:
+                return value  # DT: return the string
 
+    else:
+
+        if isinstance(value, (bool, int, float)):
+            return value
+
+        original_value = value
         if isinstance(value, bytes):
-            value = value.decode('utf-8')
+            value = value.decode(encoding)
 
         if isinstance(value, str):
             value = value.strip()
@@ -322,13 +356,37 @@ def value_2datatype(
 
             try:
                 if (
-                    len(value) >= 8
-                    and set(value[:16]).issubset(datetime_chars)
-                ):  # there could be a TimeZone
-                    return convert_datetime(date=value, convert_to=dt)
+                    ':' in value
+                    and set(value).issubset(time_chars)
+                    and (
+                        len(value) == 5  # hh:mm
+                        or len(value) == 8  # hh:mm:ss
+                    )
+                ):
+                    if dt in ('datetime', 'dt'):
+                        return parse(value).time()
+                    else:
+                        return value
+                elif get_dateformat(
+                    datestring=value,
+                    checkonly=True
+                ):
+                    if ':' in value:
+                        return convert_datetime(
+                            date=value,
+                            convert_to=dt
+                        )
+                    elif dt in ('datetime', 'dt'):
+                        return str_to_date(
+                            datestring=value
+                        )
+                    elif dt in ('DateTime', 'DT'):
+                        return str_to_DT(
+                            datestring=value
+                        )
 
             except Exception:
-                # in case it's a subset of datetime_chars but not a date or datetime
+                # in case it's a subset of datetime_chars but not a date or datetime or time
                 pass
 
             try:
