@@ -28,7 +28,7 @@ def contains_any(
     container: list,
     contained: list
 ) -> bool:
-    """ Check if at list one element of a list is contained in another list
+    """ Check if at least one element of a list is contained in another list
 
     .. note:: 'any' is not available in restricted Python
 
