@@ -8,10 +8,12 @@ import sys
 import unittest
 import datetime
 import DateTime
+from dateutil.parser import parse
 
 sys.path.append(".")
 
 from itb_data import \
+    any_2boolean, \
     create_vcard, \
     dict_2unicode, \
     dict_2datatypes, \
@@ -54,18 +56,35 @@ dicts_from_dict_list = [
     }
 ]
 
+test_boolean = {
+    True: True,
+    False: False,
+    1: True,
+    '2': True,
+    2: True,
+    0: False,
+    '0': False,
+    b'0': False,
+    'False': False,
+    'True': True,
+    b'False': False,
+    b'True': True,
+    'xyz': True,
+}
+
 dict_for_testing = {
     1: 'test one',
     '2': b'test two',
     b'3': 'test three',
-    True: 'test four',
+    True: 'test four',  # overrides 1
     'five': 5,
     b'six': True,
     b'7.0': ['1', b'2'],
     8.0: {'a': b'xy'},
     '9.0': 'False',
     b'False': b'True',
-    'x': '01.04.2022'
+    'x': '01.04.2022',
+    'y': '10:32'
 }
 
 dict_for_testing_unicoded = {
@@ -78,7 +97,8 @@ dict_for_testing_unicoded = {
     8.0: {'a': b'xy'},
     '9.0': 'False',
     'False': 'True',
-    'x': '01.04.2022'
+    'x': '01.04.2022',
+    'y': '10:32'
 }
 
 dict_for_testing_datatyped = {
@@ -91,7 +111,8 @@ dict_for_testing_datatyped = {
     8.0: {'a': b'xy'},
     9.0: False,
     False: True,
-    'x': datetime.datetime(2022, 4, 1)
+    'x': datetime.date(2022, 4, 1),
+    'y': parse('10:32').time()
 }
 
 dict_for_testing_datatyped_unicoded = {
@@ -104,7 +125,8 @@ dict_for_testing_datatyped_unicoded = {
     8.0: {'a': b'xy'},
     9.0: False,
     False: True,
-    'x': DateTime.DateTime(2022, 4, 1)
+    'x': DateTime.DateTime(2022, 4, 1),
+    'y': '10:32'
 }
 
 vcard_data = {
@@ -132,6 +154,13 @@ END:VCARD
 
 
 class TestData(unittest.TestCase):
+    def test_any_2boolean(self):
+        for a, b in test_boolean.items():
+            self.assertEqual(
+                b,
+                any_2boolean(value=a)
+            )
+
     def test_dict_from_dict_list(self):
         kwargs_list = [
             {
@@ -187,11 +216,32 @@ class TestData(unittest.TestCase):
 
     def test_dict_2datatypes(self):
         # using json data is not tested yet
+        # print('test_dict_2datatypes')
+        # print(f'{dict_for_testing           = }')
+
         datatyped_dict = dict_2datatypes(
             d=dict_for_testing,
             convert_keys=True,
             dt='datetime'
         )
+
+        # print(f'{datatyped_dict             = }')
+        # print(f'{dict_for_testing_datatyped = }')
+        self.assertEqual(
+            datatyped_dict,
+            dict_for_testing_datatyped
+        )
+
+        datatyped_dict = dict_2datatypes(
+            d=dict_for_testing,
+            metadata={
+                'x': 'date',
+                'y': 'time'
+            },
+            convert_keys=True,
+            dt='datetime'
+        )
+
         # print(f'{datatyped_dict             = }')
         # print(f'{dict_for_testing_datatyped = }')
         self.assertEqual(
