@@ -19,7 +19,7 @@ from itb_text_name import \
     sort_names, \
     could_be_a_name
 
-names = {
+reference_names = {
     'Georg Pfolz': {
         'lowercase': 'georg pfolz',
         'capitalized': 'Georg Pfolz',
@@ -90,6 +90,20 @@ names = {
             'nickname': ''
         }
     },
+    'Bea-Regina Obersteigen': {
+        'lowercase': 'bea-regina obersteigen',
+        'capitalized': 'Bea-Regina Obersteigen',
+        'gender': 'female',
+        'is_a_name': True,
+        'human_name': {
+            'title': '',
+            'first': 'Bea-Regina',
+            'middle': '',
+            'last': 'Obersteigen',
+            'suffix': '',
+            'nickname': ''
+        }
+    },
     'Roland Meier-Lansky': {
         'lowercase': 'roland meier-lansky',
         'capitalized': 'Roland Meier-Lansky',
@@ -118,6 +132,20 @@ names = {
             'nickname': ''
         }
     },
+    'Rafael': {
+        'lowercase': 'rafael',
+        'capitalized': 'Rafael',
+        'gender': 'male',
+        'is_a_name': True,
+        'human_name': {
+            'title': '',
+            'first': 'Rafael',
+            'middle': '',
+            'last': '',
+            'suffix': '',
+            'nickname': ''
+        }
+    },
     'Maria Helena Blawatsky': {
         'lowercase': 'maria helena blawatsky',
         'capitalized': 'Maria Helena Blawatsky',
@@ -148,15 +176,17 @@ names = {
     }
 }
 
-names_sorted = [
+reference_names_sorted = [
     'Maria Helena Blawatsky',
     'Eugénie Caraçon',
     'Patrizia Höfstädter',
     'DsZHkfNijWFPrET JGLAjuaqZ',
     'Joanna MacArthur',
     'Roland Meier-Lansky',
+    'Bea-Regina Obersteigen',
     'Bogumila Österreicher',
     'Georg Pfolz',
+    'Rafael',
     'Sandra de Vitt'
 ]
 
@@ -177,7 +207,7 @@ class TestTextName(unittest.TestCase):
 
     def test_leet(self):
         for _ in range(3):
-            string_to_leet = random.choice(list(names))
+            string_to_leet = random.choice(list(reference_names))
             max_length = random.randint(6, 12)
             start_at_begin = random.randint(0, 1)
 
@@ -194,7 +224,7 @@ class TestTextName(unittest.TestCase):
         # because of the use of random, using Asserts does not make any sense here
 
     def test_capitalize_name(self):
-        for name_dict in names.values():
+        for name_dict in reference_names.values():
             capitalized_name = capitalize_name(
                 text=name_dict.get('lowercase')
             )
@@ -204,7 +234,7 @@ class TestTextName(unittest.TestCase):
             )
 
     def test_get_gender(self):
-        for name, name_dict in names.items():
+        for name, name_dict in reference_names.items():
             correct_gender = name_dict.get('gender')
             gender = get_gender(name.split()[0])  # prename
 
@@ -218,7 +248,7 @@ class TestTextName(unittest.TestCase):
                 raise AssertionError(msg)
 
     def test_normalize_name(self):
-        for name, name_dict in names.items():
+        for name, name_dict in reference_names.items():
             normalized_name = normalize_name(
                 name=name
             )
@@ -237,18 +267,23 @@ class TestTextName(unittest.TestCase):
             )
 
     def test_sort_names(self):
-        names_list = list(names)
+        names_list = list(reference_names)
         sorted_names = sort_names(names=names_list)
 
         self.assertEqual(
             sorted_names,
-            names_sorted
+            reference_names_sorted
         )
 
     def test_could_be_a_name(self):
-        for name, vals in names.items():
+        for name, vals in reference_names.items():
+            kwargs = {'name': name}
+
+            if not ' ' in name:
+                kwargs['prename'] = True
+
             self.assertEqual(
-                could_be_a_name(name=name),
+                could_be_a_name(**kwargs),
                 vals.get('is_a_name')
             )
 
